@@ -85,7 +85,7 @@ class Fetch():
             auth = Auth(paths.envCwd, '[PAC PROXY]')
             getenv = enver(paths.envCwd)[0]
             username = auth.addParams('pac_user', 'PAC代理账号', value=getenv('pac_user'), defaultValue=getCurrentUser())
-            password = auth.addParams('pac_pass', 'PAC代理密码', value=getenv('pac_pass'))
+            password = auth.addParams('pac_pass', 'PAC代理密码', value=getenv('pac_pass'), isPass=True)
             logger.warning('pac认证网络, 网络交互使用代理中')
             session.proxy_auth = HTTPProxyAuth(username, password)
             self._hasPacProxy = True
